@@ -4,14 +4,16 @@ import click
 from .basic import basic
 from .pip import pip
 from .environment import environment
+from .get import get
 
 commands = [
     basic, 
     pip,
-    environment
+    environment,
+    get
 ]
 
-main = click.CommandCollection(sources=commands)
+main = click.CommandCollection(sources=commands) # type: ignore
 
 def cli():
     args = sys.argv
